@@ -30,8 +30,6 @@
 #include <QRegularExpression>
 #include <QSettings>
 
-#define OUT settings->shell->getCmdOut
-#define RUN settings->shell->run
 const extern QFile logFile;
 
 Work::Work(Settings *settings, QObject *parent)
@@ -52,12 +50,12 @@ void Work::checkEnoughSpace()
      * If both TMP work_dir and ISO don't fit on snapshot_dir, see if work_dir can be put on /home or /tmp
      * we already checked that ISO can fit on snapshot_dir so if TMP work fits on /home or /tmp move
      * the work_dir to the appropriate place and return */
-    if (OUT("stat -c '%d' " + settings->work_dir) == OUT("stat -c '%d' " + settings->snapshot_dir)) {
+    if (Cmd().getOut("stat -c '%d' " + settings->work_dir) == Cmd().getOut("stat -c '%d' " + settings->snapshot_dir)) {
         if (settings->free_space < required_space * 2) {
-            if (checkAndMoveWorkDir(QStringLiteral("/tmp"), required_space)) {
+            if (checkAndMoveWorkDir("/tmp", required_space)) {
                 return;
             }
-            if (checkAndMoveWorkDir(QStringLiteral("/home"), required_space)) {
+            if (checkAndMoveWorkDir("/home", required_space)) {
                 return;
             }
             checkNoSpaceAndExit(required_space * 2, settings->free_space,
@@ -68,61 +66,42 @@ void Work::checkEnoughSpace()
     }
 }
 
-// Checks if package is installed
 bool Work::checkInstalled(const QString &package)
 {
     qDebug() << "+++" << __PRETTY_FUNCTION__ << "+++";
-    return (OUT(QStringLiteral("dpkg -s %1 |grep Status").arg(package))
-            == QLatin1String("Status: install ok installed"));
+    return (Cmd().run(QString("dpkg -s %1 |grep '^Status: install ok installed'").arg(package)));
 }
 
-// Clean up changes before exit
 void Work::cleanUp()
 {
     if (!started) {
-        settings->shell->close();
+        shell.close();
         initrd_dir.remove();
         exit(EXIT_SUCCESS);
     }
-    settings->shell->close();
     emit message(tr("Cleaning..."));
-    QProcess::execute(QStringLiteral("sync"), {});
-
-    QProcess::execute(QStringLiteral("pkill"), {"mksquashfs"});
-    QProcess::execute(QStringLiteral("pkill"), {"md5sum"});
-    QDir::setCurrent(QStringLiteral("/"));
-    if (QFileInfo::exists(QStringLiteral("/tmp/installed-to-live/cleanup.conf"))) {
-        QProcess::execute(QStringLiteral("installed-to-live"), {"cleanup"});
+    Cmd().run(elevate + " /usr/lib/" + QCoreApplication::applicationName() + "/snapshot-lib kill_mksquashfs", true);
+    shell.close();
+    Cmd().run("sync");
+    QDir::setCurrent("/");
+    if (QFileInfo::exists("/tmp/installed-to-live/cleanup.conf")) {
+        Cmd().run(elevate + " /usr/lib/" + QCoreApplication::applicationName() + "/snapshot-lib cleanup");
     }
-
-    if (!settings->live && !settings->reset_accounts) {
-        auto homeDirs = QDir("/home").entryList(QDir::Dirs | QDir::NoDotAndDotDot);
-        for (const QString &user : homeDirs) {
-            QString desktopPath = QString("/home/%1/Desktop/minstall.desktop").arg(user);
-            QFile::remove(desktopPath);
-        }
-    }
-
-    QFile::remove(QStringLiteral("/usr/local/share/live-files/files/etc/mx-version"));
-    QFile::remove(QStringLiteral("/usr/local/share/live-files/files/etc/lsb-release"));
-
-    if (!settings->live) {
-        QFile::remove(QStringLiteral("/etc/skel/Desktop/Installer.desktop"));
-    }
-
     initrd_dir.remove();
     settings->tmpdir.reset();
     if (done) {
-        qDebug().noquote() << tr("Done");
+        emit message(tr("Done"));
+        Cmd().run(elevate + " /usr/lib/" + QCoreApplication::applicationName() + "/snapshot-lib copy_log", true);
         if (settings->shutdown) {
             QFile::copy(logFile.fileName(), settings->snapshot_dir + "/" + settings->snapshot_name + ".log");
-            QProcess::execute(QStringLiteral("sync"), {});
-            QProcess::startDetached(QStringLiteral("shutdown"), {"-h", "now"});
+            Cmd().run("sync");
+            Cmd().run("dbus-send --system --print-reply --dest=org.freedesktop.login1 /org/freedesktop/login1 "
+                      "'org.freedesktop.login1.Manager.PowerOff' boolean:true");
         }
         exit(EXIT_SUCCESS);
     } else {
-        qDebug().noquote() << tr("Done") << "\n";
-        qDebug().noquote() << QObject::tr("Interrupted or failed to complete");
+        emit message(tr("Interrupted or failed to complete"));
+        Cmd().run(elevate + " /usr/lib/" + QCoreApplication::applicationName() + "/snapshot-lib copy_log", true);
         exit(EXIT_FAILURE);
     }
 }
@@ -131,10 +110,10 @@ void Work::cleanUp()
 bool Work::checkAndMoveWorkDir(const QString &dir, quint64 req_size)
 {
     // See first if the dir is on different partition otherwise it's irrelevant
-    if (OUT("stat -c '%d' " + dir) != OUT("stat -c '%d' " + settings->snapshot_dir)
-        && settings->getFreeSpace(dir) > req_size) {
-        if (QFileInfo::exists(QStringLiteral("/tmp/installed-to-live/cleanup.conf"))) {
-            RUN(QStringLiteral("installed-to-live cleanup"));
+    if (Cmd().getOut("stat -c '%d' " + dir) != Cmd().getOut("stat -c '%d' " + settings->snapshot_dir)
+        && Settings::getFreeSpace(dir) > req_size) {
+        if (QFileInfo::exists("/tmp/installed-to-live/cleanup.conf")) {
+            Cmd().run(elevate + " /usr/lib/" + QCoreApplication::applicationName() + "/snapshot-lib cleanup");
         }
         settings->tempdir_parent = dir;
         if (!settings->checkTempDir()) {
@@ -156,9 +135,10 @@ void Work::checkNoSpaceAndExit(quint64 needed_space, quint64 free_space, const Q
         emit messageBox(
             BoxType::critical, tr("Error"),
             tr("There's not enough free space on your target disk, you need at least %1")
-                    .arg(QString::number(needed_space / factor, 'f', 2) + "GiB")
+                    .arg(QString::number(static_cast<double>(needed_space) / factor, 'f', 2) + "GiB")
                 + "\n"
-                + tr("You have %1 free space on %2").arg(QString::number(free_space / factor, 'f', 2) + "GiB", dir)
+                + tr("You have %1 free space on %2")
+                      .arg(QString::number(static_cast<double>(free_space) / factor, 'f', 2) + "GiB", dir)
                 + "\n"
                 + tr("If you are sure you have enough free space rerun the program with -o/--override-size option"));
         cleanUp();
@@ -169,16 +149,17 @@ void Work::closeInitrd(const QString &initrd_dir, const QString &file)
 {
     qDebug() << "+++" << __PRETTY_FUNCTION__ << "+++";
     QDir::setCurrent(initrd_dir);
-    RUN("(find . |cpio -o -H newc --owner root:root |gzip -9) >\"" + file + "\"");
-    makeChecksum(HashType::md5, settings->work_dir + "/iso-template/antiX", QStringLiteral("initrd.gz"));
+    shell.run("(find . |cpio -o -H newc --owner root:root |gzip -9) >\"" + file + "\"");
+    makeChecksum(HashType::md5, settings->work_dir + "/iso-template/antiX", "initrd.gz");
 }
 
 // copyModules(mod_dir/kernel kernel)
 void Work::copyModules(const QString &to, const QString &kernel)
 {
-    RUN(QStringLiteral("/usr/share/%1/scripts/copy-initrd-modules -t=\"%2\" -k=\"%3\"")
-            .arg(qApp->applicationName(), to, kernel));
-    RUN(QStringLiteral("/usr/share/%1/scripts/copy-initrd-programs --to=\"%2\"").arg(qApp->applicationName(), to));
+    shell.run(QString(R"(/usr/share/%1/scripts/copy-initrd-modules -t="%2" -k="%3")")
+                  .arg(qApp->applicationName(), to, kernel));
+    shell.runAsRoot(QString("/usr/share/%1/scripts/copy-initrd-programs --to=\"%2\"").arg(qApp->applicationName(), to));
+    shell.runAsRoot("chown -R $(logname): " + to);
 }
 
 // Copying the iso-template filesystem
@@ -187,12 +168,12 @@ void Work::copyNewIso()
     emit message(tr("Copying the new-iso filesystem..."));
     QDir::setCurrent(settings->work_dir);
 
-    RUN(QStringLiteral("tar xf /usr/lib/iso-template/iso-template.tar.gz"));
-    RUN(QStringLiteral("cp /usr/lib/iso-template/template-initrd.gz iso-template/antiX/initrd.gz"));
-    RUN("cp /boot/vmlinuz-" + settings->kernel + " iso-template/antiX/vmlinuz");
+    shell.run("tar xf /usr/lib/iso-template/iso-template.tar.gz");
+    shell.run("cp /usr/lib/iso-template/template-initrd.gz iso-template/antiX/initrd.gz");
+    shell.run("cp /boot/vmlinuz-" + settings->kernel + " iso-template/antiX/vmlinuz");
 
     replaceMenuStrings();
-    makeChecksum(HashType::md5, settings->work_dir + "/iso-template/antiX", QStringLiteral("vmlinuz"));
+    makeChecksum(HashType::md5, settings->work_dir + "/iso-template/antiX", "vmlinuz");
 
     QString path = initrd_dir.path();
     if (!initrd_dir.isValid()) {
@@ -203,8 +184,8 @@ void Work::copyNewIso()
     openInitrd(settings->work_dir + "/iso-template/antiX/initrd.gz", path);
 
     // Strip modules; make sure initrd_dir is correct to avoid disaster
-    if (path.startsWith(QStringLiteral("/tmp/"))) {
-        QDir modulesDir(path + QStringLiteral("/lib/modules"));
+    if (path.startsWith("/tmp/")) {
+        QDir modulesDir(path + "/lib/modules");
         if (modulesDir.exists()) {
             modulesDir.removeRecursively();
         }
@@ -240,30 +221,28 @@ bool Work::createIso(const QString &filename)
 {
     qDebug() << "+++" << __PRETTY_FUNCTION__ << "+++";
     // Squash the filesystem copy
-    QDir::setCurrent(settings->work_dir);
-    QString maybe_unbuffer = (settings->cli_mode && checkInstalled(QStringLiteral("expect")))
-                                 ? QStringLiteral("unbuffer ")
-                                 : QLatin1String("");
-    QString cmd = maybe_unbuffer + "mksquashfs /.bind-root iso-template/antiX/linuxfs -comp " + settings->compression
-                  + ((settings->mksq_opt.isEmpty()) ? QLatin1String("") : " " + settings->mksq_opt) + " -wildcards -ef "
+    QString unbuffer = (checkInstalled("expect")) ? "unbuffer " : "stdbuf -o0 ";
+    QString cmd = unbuffer + "mksquashfs /.bind-root " + settings->work_dir + "/iso-template/antiX/linuxfs -comp "
+                  + settings->compression + " -processors " + QString::number(settings->cores) + " -throttle "
+                  + QString::number(settings->throttle)
+                  + ((settings->mksq_opt.isEmpty()) ? "" : " " + settings->mksq_opt) + " -wildcards -ef "
                   + settings->snapshot_excludes.fileName() + " " + settings->session_excludes;
 
     emit message(tr("Squashing filesystem..."));
-    QString out;
-    if (!RUN(cmd, &out)) {
+    if (!shell.runAsRoot(cmd)) {
         emit messageBox(BoxType::critical, tr("Error"),
                         tr("Could not create linuxfs file, please check whether you have enough space on the "
                            "destination partition."));
         return false;
     }
-    writeUnsquashfsSize(out);
+    writeUnsquashfsSize(shell.readAllOutput());
 
     // Move linuxfs files to iso-2/antiX folder
-    QDir().mkpath(QStringLiteral("iso-2/antiX"));
-    RUN(QStringLiteral("mv iso-template/antiX/linuxfs* iso-2/antiX"));
-    makeChecksum(HashType::md5, settings->work_dir + "/iso-2/antiX", QStringLiteral("linuxfs"));
+    QDir().mkpath("iso-2/antiX");
+    shell.run("mv iso-template/antiX/linuxfs* iso-2/antiX");
+    makeChecksum(HashType::md5, settings->work_dir + "/iso-2/antiX", "linuxfs");
 
-    RUN(QStringLiteral("installed-to-live cleanup"));
+    Cmd().run(elevate + " /usr/lib/" + QCoreApplication::applicationName() + "/snapshot-lib cleanup");
 
     // Create the iso file
     QDir::setCurrent(settings->work_dir + "/iso-template");
@@ -272,7 +251,7 @@ bool Work::createIso(const QString &filename)
           "boot/isolinux/isolinux.cat -o \""
           + settings->snapshot_dir + "/" + filename + "\" . \"" + settings->work_dir + "/iso-2\"";
     emit message(tr("Creating CD/DVD image file..."));
-    if (!RUN(cmd)) {
+    if (!shell.run(cmd)) {
         emit messageBox(
             BoxType::critical, tr("Error"),
             tr("Could not create ISO file, please check whether you have enough space on the destination partition."));
@@ -282,7 +261,7 @@ bool Work::createIso(const QString &filename)
     // Make it isohybrid
     if (settings->make_isohybrid) {
         emit message(tr("Making hybrid iso"));
-        RUN("isohybrid --uefi \"" + settings->snapshot_dir + "/" + filename + "\"");
+        shell.run("isohybrid --uefi \"" + settings->snapshot_dir + "/" + filename + "\"");
     }
 
     // Make ISO checksums
@@ -292,10 +271,9 @@ bool Work::createIso(const QString &filename)
     if (settings->make_sha512sum) {
         makeChecksum(HashType::sha512, settings->snapshot_dir, filename);
     }
-    RUN("chown $(logname):$(logname) \"" + settings->snapshot_dir + "/" + filename + "\"*");
 
     QTime time(0, 0);
-    time = time.addMSecs(e_timer.elapsed());
+    time = time.addMSecs(static_cast<int>(e_timer.elapsed()));
     emit message(tr("Done"));
     if (settings->shutdown) {
         done = true;
@@ -303,18 +281,17 @@ bool Work::createIso(const QString &filename)
     }
     emit messageBox(BoxType::information, tr("Success"),
                     tr("MX Snapshot completed sucessfully!") + "\n"
-                        + tr("Snapshot took %1 to finish.").arg(time.toString(QStringLiteral("hh:mm:ss"))) + "\n\n"
+                        + tr("Snapshot took %1 to finish.").arg(time.toString("hh:mm:ss")) + "\n\n"
                         + tr("Thanks for using MX Snapshot, run MX Live USB Maker next!"));
     done = true;
     return true;
 }
 
-// Installs package
 bool Work::installPackage(const QString &package)
 {
     emit message(tr("Installing ") + package);
-    RUN(QStringLiteral("apt-get update"));
-    if (!RUN("apt-get install -y " + package)) {
+    shell.runAsRoot("apt-get update");
+    if (!shell.runAsRoot("apt-get install -y " + package)) {
         emit messageBox(BoxType::critical, tr("Error"), tr("Could not install ") + package);
         return false;
     }
@@ -326,12 +303,12 @@ void Work::makeChecksum(Work::HashType hash_type, const QString &folder, const Q
 {
     qDebug() << "+++" << __PRETTY_FUNCTION__ << "+++";
     emit message(tr("Calculating checksum..."));
-    RUN(QStringLiteral("sync"));
+    shell.run("sync");
     QDir::setCurrent(folder);
     QString ce = QVariant::fromValue(hash_type).toString();
     QString cmd;
     QString checksum_cmd = ("%1sum \"" + file_name + "\">\"" + folder + "/" + file_name + ".%1\"").arg(ce);
-    QString temp_dir = QStringLiteral("/tmp/snapsphot-checksum-temp");
+    QString temp_dir {"/tmp/snapsphot-checksum-temp"};
     QString checksum_tmp
         = ("TD=" + temp_dir + "; KEEP=$TD/.keep; [ -d $TD ] || mkdir $TD ; FN=\"" + file_name + "\"; CF=\"" + folder
            + "/${FN}.%1\"; cp $FN $TD/$FN; pushd $TD>/dev/null; %1sum $FN > $FN.%1 ; cp $FN.%1 "
@@ -340,8 +317,8 @@ void Work::makeChecksum(Work::HashType hash_type, const QString &folder, const Q
 
     if (settings->preempt) {
         // Check free space available on /tmp
-        RUN("TF=/tmp/snapsphot-checksum-temp/\"" + file_name + R"("; [ -f "$TF" ] && rm -f "$TF")");
-        if (!RUN(
+        shell.run("TF=/tmp/snapsphot-checksum-temp/\"" + file_name + R"("; [ -f "$TF" ] && rm -f "$TF")");
+        if (!shell.run(
                 "DUF=$(du -BM " + file_name
                 + "|grep -oE '^[[:digit:]]+'); TDA=$(df -BM --output=avail /tmp |grep -oE '^[[:digit:]]+'); ((TDA/10*8 "
                   ">= DUF))")) {
@@ -352,10 +329,12 @@ void Work::makeChecksum(Work::HashType hash_type, const QString &folder, const Q
         cmd = checksum_cmd;
     } else {
         // Free pagecache
-        RUN(QStringLiteral("sync; sleep 1; echo 1 > /proc/sys/vm/drop_caches; sleep 1"));
+        shell.run("sync; sleep 1");
+        Cmd().run(elevate + " /usr/lib/" + QCoreApplication::applicationName() + "/snapshot-lib drop_caches");
+        shell.run("sleep 1");
         cmd = checksum_tmp;
     }
-    RUN(cmd);
+    shell.run(cmd);
     QDir::setCurrent(settings->work_dir);
 }
 
@@ -363,9 +342,9 @@ void Work::openInitrd(const QString &file, const QString &initrd_dir)
 {
     qDebug() << "+++" << __PRETTY_FUNCTION__ << "+++";
     emit message(tr("Building new initrd..."));
-    RUN("chmod a+rx \"" + initrd_dir + "\"");
+    shell.run("chmod a+rx \"" + initrd_dir + "\"");
     QDir::setCurrent(initrd_dir);
-    RUN(QStringLiteral("gunzip -c \"%1\" |cpio -idum").arg(file));
+    shell.run(QString("gunzip -c \"%1\" |cpio -idum").arg(file));
 }
 
 // Replace text in menu items in grub.cfg, syslinux.cfg, isolinux.cfg
@@ -373,55 +352,51 @@ void Work::replaceMenuStrings()
 {
     qDebug() << "+++" << __PRETTY_FUNCTION__ << "+++";
     QString full_distro_name_space = settings->full_distro_name;
-    full_distro_name_space.replace(QLatin1String("_"), QLatin1String(" "));
+    full_distro_name_space.replace("_", " ");
 
-    const QString grub_cfg = QStringLiteral("/iso-template/boot/grub/grub.cfg");
-    replaceStringInFile(QStringLiteral("%DISTRO%"), settings->project_name + "-" + settings->distro_version,
+    const QString grub_cfg {"/iso-template/boot/grub/grub.cfg"};
+    replaceStringInFile("%DISTRO%", settings->project_name + "-" + settings->distro_version,
                         settings->work_dir + grub_cfg);
-    replaceStringInFile(QStringLiteral("%DISTRO_NAME%"), settings->project_name, settings->work_dir + grub_cfg);
-    replaceStringInFile(QStringLiteral("%FULL_DISTRO_NAME%"), settings->full_distro_name,
-                        settings->work_dir + grub_cfg);
-    replaceStringInFile(QStringLiteral("%FULL_DISTRO_NAME_SPACE%"), full_distro_name_space,
-                        settings->work_dir + grub_cfg);
-    replaceStringInFile(QStringLiteral("%RELEASE_DATE%"), settings->release_date, settings->work_dir + grub_cfg);
+    replaceStringInFile("%DISTRO_NAME%", settings->project_name, settings->work_dir + grub_cfg);
+    replaceStringInFile("%FULL_DISTRO_NAME%", settings->full_distro_name, settings->work_dir + grub_cfg);
+    replaceStringInFile("%FULL_DISTRO_NAME_SPACE%", full_distro_name_space, settings->work_dir + grub_cfg);
+    replaceStringInFile("%RELEASE_DATE%", settings->release_date, settings->work_dir + grub_cfg);
 
-    const QString grubenv_cfg = QStringLiteral("/iso-template/boot/grub/grubenv.cfg");
-    const QString boot_pararameter_regexp = QStringLiteral("^(lang=|kbd=|kbvar=|kbopt=|tz=)");
-    RUN(QStringLiteral("printf '%s\\n' %1 | grep -E '%2' >> '%3'")
-            .arg(settings->boot_options, boot_pararameter_regexp, settings->work_dir + grubenv_cfg));
-    RUN(QStringLiteral("sed -i \"s|%OPTIONS%|$(printf '%s\\n' %1 | grep -v -E '%2' | tr '\\n' ' ')|\" '%3'")
-            .arg(settings->boot_options, boot_pararameter_regexp, settings->work_dir + grub_cfg));
+    const QString grubenv_cfg {"/iso-template/boot/grub/grubenv.cfg"};
+    const QString boot_pararameter_regexp {"^(lang=|kbd=|kbvar=|kbopt=|tz=)"};
+    shell.run(QString("printf '%s\\n' %1 | grep -E '%2' >> '%3'")
+                  .arg(settings->boot_options, boot_pararameter_regexp, settings->work_dir + grubenv_cfg));
+    shell.run(QString(R"(sed -i "s|%OPTIONS%|$(printf '%s\n' %1 | grep -v -E '%2' | tr '\n' ' ')|" '%3')")
+                  .arg(settings->boot_options, boot_pararameter_regexp, settings->work_dir + grub_cfg));
 
-    const QString syslinux_cfg = QStringLiteral("/iso-template/boot/syslinux/syslinux.cfg");
-    const QString isolinux_cfg = QStringLiteral("/iso-template/boot/isolinux/isolinux.cfg");
+    const QString syslinux_cfg {"/iso-template/boot/syslinux/syslinux.cfg"};
+    const QString isolinux_cfg {"/iso-template/boot/isolinux/isolinux.cfg"};
     for (const QString &file : {syslinux_cfg, isolinux_cfg}) {
-        replaceStringInFile(QStringLiteral("%OPTIONS%"), settings->boot_options, settings->work_dir + file);
-        replaceStringInFile(QStringLiteral("%CODE_NAME%"), settings->codename, settings->work_dir + file);
+        replaceStringInFile("%OPTIONS%", settings->boot_options, settings->work_dir + file);
+        replaceStringInFile("%CODE_NAME%", settings->codename, settings->work_dir + file);
     }
 
-    const QString sys_readme = QStringLiteral("/iso-template/boot/syslinux/readme.msg");
-    const QString iso_readme = QStringLiteral("/iso-template/boot/isolinux/readme.msg");
+    const QString sys_readme = "/iso-template/boot/syslinux/readme.msg";
+    const QString iso_readme = "/iso-template/boot/isolinux/readme.msg";
     const QStringList cfg_files {syslinux_cfg, isolinux_cfg, sys_readme, iso_readme};
     for (const QString &file : cfg_files) {
-        replaceStringInFile(QStringLiteral("%FULL_DISTRO_NAME%"), settings->full_distro_name,
-                            settings->work_dir + file);
-        replaceStringInFile(QStringLiteral("%RELEASE_DATE%"), settings->release_date, settings->work_dir + file);
+        replaceStringInFile("%FULL_DISTRO_NAME%", settings->full_distro_name, settings->work_dir + file);
+        replaceStringInFile("%RELEASE_DATE%", settings->release_date, settings->work_dir + file);
     }
 
     QString themeDir = settings->work_dir + "/iso-template/boot/grub/theme";
     QDirIterator themeFileIt(themeDir, {"*.txt"}, QDir::Files);
     while (themeFileIt.hasNext()) {
         QString themeFile = themeFileIt.next();
-        replaceStringInFile(QStringLiteral("%ASCII_CODE_NAME%"), settings->codename, themeFile);
-        replaceStringInFile(QStringLiteral("%DISTRO%"), settings->project_name + "-" + settings->distro_version,
-                            themeFile);
+        replaceStringInFile("%ASCII_CODE_NAME%", settings->codename, themeFile);
+        replaceStringInFile("%DISTRO%", settings->project_name + "-" + settings->distro_version, themeFile);
     }
 }
 
 // Util function for replacing strings in files
 bool Work::replaceStringInFile(const QString &old_text, const QString &new_text, const QString &file_path)
 {
-    return RUN(QStringLiteral("sed -i 's|%1|%2|g' \"%3\"").arg(old_text, new_text, file_path));
+    return shell.runAsRoot(QString("sed -i 's|%1|%2|g' %3").arg(old_text, new_text, file_path));
 }
 
 // Save package list in working directory
@@ -438,7 +413,7 @@ void Work::savePackageList(const QString &file_name)
     QString cmd
         = R"(dpkg -l |grep ^ii\ \ |awk '{print $2,$3}' |sed 's/:'$(dpkg --print-architecture)'//' |column -t >")"
           + full_name + "\"";
-    RUN(cmd);
+    shell.run(cmd);
 }
 
 // Setup the environment before taking the snapshot
@@ -446,20 +421,20 @@ void Work::setupEnv()
 {
     qDebug() << "+++" << __PRETTY_FUNCTION__ << "+++";
     // Checks if work_dir looks OK
-    if (!settings->work_dir.contains(QLatin1String("/mx-snapshot"))) {
+    if (!settings->work_dir.contains("/mx-snapshot")) {
         cleanUp();
     }
 
-    QString bind_boot = QLatin1String("");
-    QString bind_boot_too = QLatin1String("");
-    if (RUN(QStringLiteral("mountpoint /boot"))) {
-        bind_boot = QStringLiteral("bind=/boot ");
-        bind_boot_too = QStringLiteral(",/boot");
+    QString bind_boot;
+    QString bind_boot_too;
+    if (shell.run("mountpoint /boot")) {
+        bind_boot = "bind=/boot ";
+        bind_boot_too = ",/boot";
     }
 
     // Install mx-installer if absent
-    if (settings->force_installer && !checkInstalled(QStringLiteral("mx-installer"))) {
-        installPackage(QStringLiteral("mx-installer"));
+    if (settings->force_installer && !checkInstalled("mx-installer")) {
+        installPackage("mx-installer");
     }
 
     writeSnapshotInfo();
@@ -468,28 +443,17 @@ void Work::setupEnv()
 
     // Setup environment if creating a respin (reset root/demo, remove personal accounts)
     if (settings->reset_accounts) {
-        RUN("installed-to-live -b /.bind-root start " + bind_boot + "empty=/home general version-file read-only");
+        shell.runAsRoot("installed-to-live -b /.bind-root start " + bind_boot
+                        + "empty=/home general version-file read-only");
     } else {
-        //        if (settings->force_installer) { // copy minstall.desktop to Desktop on all accounts
-        //            RUN("echo /home/*/Desktop |xargs -n1 cp /usr/share/applications/minstall.desktop 2>/dev/null");
-        //            RUN("echo /home/*/Desktop/minstall.desktop |xargs -n1 sed -i
-        //            's/^NoDisplay=true/NoDisplay=false/'");
-        //            // Needs write access to remove lock symbol on installer on desktop, executable to run it
-        //            RUN("chmod 777 /home/*/Desktop/minstall.desktop");
-        //            if (!QFile::exists("/usr/bin/xdg-user-dirs-update.real")) {
-        //                QDir().mkdir("/etc/skel/Desktop");
-        //                QFile::copy("/usr/share/applications/minstall.desktop",
-        //                "/etc/skel/Desktop/Installer.desktop"); RUN("chmod 755 /etc/skel/Desktop/Installer.desktop");
-        //            }
-        //        }
-        RUN("installed-to-live -b /.bind-root start bind=/home" + bind_boot_too
-            + " live-files version-file adjtime read-only");
+        shell.runAsRoot("installed-to-live -b /.bind-root start bind=/home" + bind_boot_too
+                        + " live-files version-file adjtime read-only");
     }
 }
 
 void Work::writeLsbRelease()
 {
-    QFile file(QStringLiteral("/usr/local/share/live-files/files/etc/lsb-release"));
+    QFile file("/usr/local/share/live-files/files/etc/lsb-release");
     if (!file.open(QFile::WriteOnly | QFile::Truncate)) {
         return;
     }
@@ -508,19 +472,19 @@ void Work::writeLsbRelease()
 // Write date of the snapshot in a "snapshot_created" file
 void Work::writeSnapshotInfo()
 {
-    QFile file(QStringLiteral("/usr/local/share/live-files/files/etc/snapshot_created"));
+    QFile file("/usr/local/share/live-files/files/etc/snapshot_created");
     if (!file.open(QFile::WriteOnly | QFile::Truncate)) {
         return;
     }
 
     QTextStream stream(&file);
-    stream << QDateTime::currentDateTime().toString(QStringLiteral("yyyyMMdd_HHmm"));
+    stream << QDateTime::currentDateTime().toString("yyyyMMdd_HHmm");
     file.close();
 }
 
 void Work::writeVersionFile()
 {
-    QFile file(QStringLiteral("/usr/local/share/live-files/files/etc/mx-version"));
+    QFile file("/usr/local/share/live-files/files/etc/mx-version");
     if (!file.open(QFile::WriteOnly | QFile::Truncate)) {
         return;
     }
@@ -533,9 +497,8 @@ void Work::writeVersionFile()
 void Work::writeUnsquashfsSize(const QString &text)
 {
     QSettings file(settings->work_dir + "/iso-template/antiX/linuxfs.info", QSettings::NativeFormat);
-    file.setValue(QStringLiteral("UncompressedSizeKB"),
-                  text.section(QRegularExpression(QStringLiteral(" uncompressed filesystem size \\(")), 1, 1)
-                      .section(QStringLiteral(" "), 0, 0));
+    file.setValue("UncompressedSizeKB",
+                  text.section(QRegularExpression(" uncompressed filesystem size \\("), 1, 1).section(" ", 0, 0));
 }
 
 quint64 Work::getRequiredSpace()
@@ -568,7 +531,7 @@ quint64 Work::getRequiredSpace()
         }
     }
 
-    QString root_dev = OUT(QStringLiteral("df /.bind-root --output=target |tail -1"), true);
+    QString root_dev = Cmd().getOut("df /.bind-root --output=target |tail -1", true);
     QMutableStringListIterator it(excludes);
     while (it.hasNext()) {
         it.next();
@@ -580,29 +543,28 @@ quint64 Work::getRequiredSpace()
         it.value().replace(QLatin1String("("), QLatin1String("\\("));
         it.value().replace(QLatin1String(")"), QLatin1String("\\)"));
         it.value().replace(QLatin1String("|"), QLatin1String("\\|"));
-        it.value().prepend("/.bind-root/"); // check size occupied by excluded files on /.bind-root only
-        it.value().remove(QRegularExpression(QStringLiteral("\\*$"))); // chop last *
+        it.value().prepend("/.bind-root/");            // check size occupied by excluded files on /.bind-root only
+        it.value().remove(QRegularExpression("\\*$")); // chop last *
         // Remove from list if files not on the same volume
-        if (root_dev
-            != OUT(QStringLiteral("df ") + it.value() + QStringLiteral(" --output=target 2>/dev/null |tail -1"),
-                   true)) {
+        if (root_dev != Cmd().getOut("df " + it.value() + " --output=target 2>/dev/null |tail -1", true)) {
             it.remove();
         }
     }
     emit message(tr("Calculating total size of excluded files..."));
     bool ok = false;
-    QString cmd = settings->live ? QStringLiteral("du -sc") : QStringLiteral("du -sxc");
-    quint64 excl_size = OUT(cmd + " {" + excludes.join(QStringLiteral(",")).remove(QStringLiteral("/.bind-root,"))
-                            + "} 2>/dev/null |tail -1 |cut -f1")
-                            .toULongLong(&ok);
+    QString cmd = settings->live ? "du -sc" : "du -sxc";
+    quint64 excl_size
+        = shell.getOutAsRoot(cmd + " {" + excludes.join(",").remove("/.bind-root,") + "} 2>/dev/null |tail -1 |cut -f1")
+              .toULongLong(&ok);
     if (!ok) {
         qDebug() << "Error: calculating size of excluded files\n"
                     "If you are sure you have enough free space rerun the program with -o/--override-size option";
         cleanUp();
     }
     emit message(tr("Calculating size of root..."));
-    cmd = settings->live ? QStringLiteral("du -s") : QStringLiteral("du -sx");
-    quint64 root_size = OUT(cmd + QStringLiteral(" /.bind-root 2>/dev/null |tail -1 |cut -f1")).toULongLong(&ok);
+    cmd = settings->live ? "du -s" : "du -sx";
+    quint64 root_size = shell.getOutAsRoot(cmd + " /.bind-root 2>/dev/null |tail -1 |cut -f1").toULongLong(&ok);
+    qDebug() << "SIZE" << root_size;
     if (!ok) {
         qDebug() << "Error: calculating root size (/.bind-root)\n"
                     "If you are sure you have enough free space rerun the program with -o/--override-size option";
